import json
import pandas as pd
from sqlalchemy import create_engine

class mysqlUtil:
    def __init__(self):
        __mysql_username = 'test'
        __mysql_password = 'test'
        # 填写真实数库ip
        __mysql_ip = 'home.hddly.cn'
        __port = 53306
        __db = 'test'
        # 初始化数据库连接,使用pymysql库
        self.engine = create_engine(
            'mysql+pymysql://{}:{}@{}:{}/{}'.format(__mysql_username, __mysql_password, __mysql_ip, __port, __db))

    # 查询mysql数据库
    def query(self, sql):
        df = pd.read_sql_query(sql, self.engine)
        # df = pandas.read_sql(sql,self.engine)     这种读取方式也可以

        # 返回dateframe格式
        return df

    def select_rand_db(self, types=None):
        if types:
            sql = "select ip,port,types from eie_ip where types='{}' order by rand() limit 1".format(types)
        else:
            sql = "select ip,port,types from eie_ip order by rand() limit 1 "
        df = pd.read_sql(sql, self.engine)
        results = json.loads(df.to_json(orient='records'))
        if results and len(results) == 1:
            return results[0]
        return None



import pymongo

def insertMongdbOne(collecter,title,url,content):
    client = pymongo.MongoClient('home.hddly.cn:57017')
    db = client['pythondb']  # 选择pythondb
    collection = db.test  # 使用 test集合
    # info = {'title': title, 'url': url, 'content': content, 'collecter': collecter}
    info = {'title': title, 'url': url, 'collecter': collecter}
    print(info)
    collection.insert_one(info)
    client.close()  # 关闭Mongodb连接




import paramiko
class ftpUtil:
    # 登陆参数设置
    __hostname = "home.hddly.cn"
    __host_port = 8021
    __username_media = "ftpuser"
    __password_media = "ywq20120721"
    __username_stud ="student"
    __password_stud ="student"
    __remotedir_media = "/media/"
    __remotedir_stud = "/send/"

    def putfile_stud(self,local_path,remote_file):
        # # 要传输文件的路径
        # filepath = "./myname.jpg"
        # # 上传后的传输文件的文件名
        # filename = "drawpic_myname.jpg" #请将myname改为本人学号
        try:
            transport = paramiko.Transport((self.__hostname, self.__host_port))
            transport.connect(username=self.__username_stud, password=self.__password_stud)
            sftp = paramiko.SFTPClient.from_transport(transport)
            sftp.chdir(self.__remotedir_stud)
            sftp.put(local_path,remote_file)
            print('上传成功......')
            sftp.close()
            transport.close()
        except:
            print('连接失败......')

    def putfile_media(self,local_path,remote_file):
        t = paramiko.Transport((self.__hostname, self.__host_port))
        t.connect(username=self.__username_media, password=self.__password_media)
        sftp = paramiko.SFTPClient.from_transport(t)
        remote_path = self.__remotedir_media + remote_file  # 远程路径
        put_info = sftp.put(local_path, remote_path, confirm=True)
        print(put_info)
        print(f"finished put file:{local_path}.")
        t.close

    def getfile_media(self,remote_file,local_path):
        t = paramiko.Transport((self.__username_media, self.__host_port))
        t.connect(username=self.__username_media, password=self.__password_media)
        sftp = paramiko.SFTPClient.from_transport(t)
        remote_path = self.__remotedir_media + remote_file  # 远程路径
        sftp.get(remotepath=remote_path, localpath=local_path)
        print(f"finished get file:{local_path}.")
        t.close



from __future__ import print_function
from setuptools import setup, find_packages

setup(
    name="bgutils_hddly",
    version="1.0.09",
    author="hddly",  #作者名字
    author_email="goodym@163.com",
    description="bigdata utils.",
    license="MIT",
    url="https://bigdata.hddly.cn",  #github地址或其他地址
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Environment :: Web Environment",
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    install_requires=[
            'pandas>=0.20.0',  #所需要包的版本号
            'numpy>=1.14.0'   #所需要包的版本号
    ],
    zip_safe=True,
)
